# -*- coding: utf-8 -*-
#
# Copyright (C) 2006-2007 Edgewall Software
# All rights reserved.
#
# This software is licensed as described in the file COPYING, which
# you should have received as part of this distribution. The terms
# are also available at http://posterity.edgewall.org/wiki/License.
#
# This software consists of voluntary contributions made by many
# individuals. For the exact contribution history, see the revision
# history and logs, available at http://posterity.edgewall.org/log/.

from elixir import objectstore

from posterity.admin import AdminCommand
from posterity.model import Account
from posterity.util import encrypt_password


class AccountCommand(AdminCommand):
    cmd_name = 'account'
    short_help = 'create/update accounts'
    usage = '%prog account [options] username'

    def setup_optparser(self):
        self.parser.add_option("-c", "--create", dest="create", 
                                       action="store_true",
                                       help="create account", default=False)
        self.parser.add_option("-l", "--list", dest="list", 
                                       action="store_true",
                                       help="list accounts", default=False)
        self.parser.add_option("-p", "--password", dest="password", 
                                       metavar='PASSWORD',
                                       help="set password")
    def finalize_options(self):
        if self.options.list:
            if len(self.args) != 0:
                self.parser.error('Invalid number of arguments')
        else:
            if len(self.args) != 1:
                self.parser.error('Invalid number of arguments')
            self.username = self.args[0]

    def run(self):
        if self.options.list:
            for a in Account.select():
                print 'Username'
                print '--------'
                print a.username
        elif self.options.create:
            self.log.info('Adding account "%s"' % self.username)
            a = Account.create(self.username)
            objectstore.flush()
            print 'Account "%s" created.' % self.username
        if self.options.password:
            a = Account.get_by(username=self.username)
            self.log.info('Updating password for account "%s"' % self.username)
            a.set_password(self.options.password)
            print 'Password updated'
