# -*- coding: utf-8 -*-
#
# Copyright (C) 2007 Edgewall Software
# All rights reserved.
#
# This software is licensed as described in the file COPYING, which
# you should have received as part of this distribution. The terms
# are also available at http://posterity.edgewall.org/wiki/License.
#
# This software consists of voluntary contributions made by many
# individuals. For the exact contribution history, see the revision
# history and logs, available at http://posterity.edgewall.org/log/.

from elixir import objectstore
from paste.httpexceptions import HTTPNotFound

from posterity import log, request, session
from posterity.component import Component, implements, Interface
from posterity.core import IRoutesProvider, ISettingsPanel, IMessageFilter
from posterity.model import Pop3Account
from posterity.util.i18n import _
from posterity.util.validators import Pop3AccountSchema
from posterity.web import flash, redirect, send_template, validate


class Pop3Controller(Component):

    implements(IRoutesProvider, ISettingsPanel)

    def index(self, environ, start_response):
        data = dict(paccounts=Pop3Account.select_by(account=session.account))
        return send_template(start_response, 'pop3_list.html', data)

    @validate(schema=Pop3AccountSchema, on_error='/pop3')
    def create(self, environ, start_response):
        paccount = Pop3Account(account=session.account, **request.formvars)
        paccount.enabled = True
        objectstore.flush()
        flash('POP3 Account added')
        return redirect(start_response, '/pop3')

    @validate(schema=Pop3AccountSchema)
    def update(self, environ, start_response):
        paccount = Pop3Account.get_by(id=request.urlvars['id'],
                                  account=session.account)
        if not paccount:
            return HTTPNotFound()(environ, start_response)
        for k, v in request.formvars.items():
            setattr(paccount, k, v)
        objectstore.flush()
        flash('POP3 account updated')
        return redirect(start_response, '/pop3')
    
    def delete(self, environ, start_response):
        paccount = Pop3Account.get_by(id=request.urlvars['id'],
                                  account=session.account)
        if not paccount:
            return HTTPNotFound()(environ, start_response)
        objectstore.delete(paccount)
        flash('POP3 account deleted')
        return redirect(start_response, '/pop3')

    def edit_form(self, environ, start_response):
        paccount = Pop3Account.get_by(id=request.urlvars['id'],
                                  account=session.account)
        if not paccount:
            return HTTPNotFound()(environ, start_response)
        data = dict(paccount=paccount)
        return send_template(start_response, 'pop3_edit.html', data)

    ## IRoutesProvider methods
    def add_routes(self, routes):
        routes.add('/pop3/{id}', GET=self.edit_form,
                                    PUT=self.update,
                                    DELETE=self.delete)
        routes.add('/pop3', GET=self.index, POST=self.create)

    ## ISettingsPanel methods
    def get_settings_panels(self):
        yield dict(label=_('POP3 Accounts'), href='/pop3')

