# -*- coding: utf-8 -*-
#
# Copyright (C) 2006-2007 Edgewall Software
# All rights reserved.
#
# This software is licensed as described in the file COPYING, which
# you should have received as part of this distribution. The terms
# are also available at http://posterity.edgewall.org/wiki/License.
#
# This software consists of voluntary contributions made by many
# individuals. For the exact contribution history, see the revision
# history and logs, available at http://posterity.edgewall.org/log/.

from elixir import objectstore
import pkg_resources

from posterity.admin.admin import run_admin
from posterity.model import Account, Tag
from posterity.tests.fixtures import PosterityTestApp

def setup_module():
    global app
    app = PosterityTestApp()

def teardown_module():
    app.teardown_instance()

def test_create_filter():
    app.login('testuser')
    resp = app.get('/tags/Inbox/convs')
    resp = resp.click('Settings').click('Filters')
    form = resp.forms['create-filter']
    form.set('from_', 'from_condition')
    form.set('to', 'to_condition')
    form.set('subject', 'subject_condition')
    form.set('contains', 'contains_condition')
    form.set('archive', True)
    form.set('delete', True)
    resp = form.submit().follow()
    form.set('to', 'to_condition')
    resp.mustcontain('from_condition', 'to_condition', 'subject_condition',
                     'contains_condition',
                     'Archive message', 'Delete message')
    
def test_modify_filter():
    resp = app.get('/filters')
    resp = resp.click('from_condition')
    form = resp.forms['edit-filter']
    form.set('from_', 'from2_condition')
    resp = form.submit().follow()
    resp.mustcontain('from2_condition', 'to_condition', 'subject_condition',
                     'contains_condition',
                     'Archive message', 'Delete message')
    
def test_delete_filter():
    resp = app.get('/filters')
    resp = resp.click('from2_condition')
    form = resp.forms['delete-filter']
    resp = form.submit().follow()
    assert not 'from2_condition' in resp

def test_filter1():
    # Add a tag called 'John'
    account = Account.get_by(username='testuser')
    tag = Tag(account=account, name='John')
    # Tag all messages from John with a John-tag and archvie them
    objectstore.flush()
    resp = app.get('/filters')
    form = resp.forms['create-filter']
    form.set('from_', 'john@example.com')
    form.set('archive', True)
    form.set('tag', 'John')
    resp = form.submit().follow()
    # Verify that messages from john are correctly tagged
    assert len(tag.get_convs()) == 0
    emails = pkg_resources.resource_listdir('posterity.admin', 'tests/data')
    filename = pkg_resources.resource_filename('posterity.admin', 
                                               'tests/data/email1.eml')
    run_admin(['posterity-admin', 'inject', '-f', filename, 
               '-i', app.instance.path, 'testuser'])
    convs = tag.get_convs()
    assert len(convs) == 1
    assert not Tag.get_by(account=account, name='Inbox') in convs[0].tags
